querys = {
    "k3_2": "select * from laulud",
    #"p2_1": "SELECT COUNT(nimi) AS arv FROM Riigid WHERE LENGTH(nimi)=7 AND LEFT(nimi,1)= 'A';",
    #"p2_2": "SELECT pealkiri FROM laulud WHERE RIGHT(pealkiri,1) = 'a' AND punktid_finaalis BETWEEN 100 AND 200; ",
    #"p3_1": """SELECT keel, COUNT(id) AS arv FROM laulud WHERE keel NOT LIKE '%English%' AND finaalis='1' GROUP BY keel ORDER BY 2 DESC, 1 LIMIT 10;""",
    #"p3_2": """SELECT LEFT(pealkiri,4) AS pealkirja_algus, count(id) AS arv FROM laulud GROUP BY "pealkirja_algus" HAVING count(id)>4;""",
    #"p4_1": """SELECT lavanimi, nimi FROM Lauljad, Riigid WHERE lauljad.synniriik_id =Riigid.ID""",
    #"p4_2": """SELECT pealkiri, punktid_finaalis, koht_finaalis FROM Laulud, Riigid WHERE Laulud.Riik_Id=Riigid.Id AND Nimi='Estonia'""",
    #"p4_3": """SELECT pealkiri, punktid_finaalis, koht_finaalis FROM Laulud, Riigid WHERE Laulud.Riik_Id=Riigid.Id AND Nimi='Estonia' AND koht_finaalis IS NOT NULL""",
    #"p4_4": """SELECT nimi, pealkiri FROM Riigid, Laulud, Voistlused WHERE Laulud.Riik_id=Riigid.id AND Laulud.Voistlus_id=Voistlused.id AND EXTRACT (YEAR FROM Finaali_kuupaev) = 2019;""",
    #"p4_5": "SELECT linn, SUM(punktid_finaalis) AS kokku, MAX(punktid_finaalis) AS maksimaalne FROM Voistlused, Laulud WHERE Voistlused.Id=Laulud.Voistlus_ID GROUP BY linn ORDER BY 2 DESC; ",
    #"p6_2": """SELECT EXTRACT (YEAR FROM finaali_kuupaev) as Aasta, lavanimi AS Esineja, pealkiri AS Laul, keel, punktid_finaalis AS Punktid, koht_finaalis AS Koht FROM v_lauluesitamine, Voistlused, Riigid WHERE v_lauluesitamine.Voistlus_Id=Voistlused.id AND v_lauluesitamine.Lauluriik_id=Riigid.Id AND Riigid.nimi ='Estonia' ORDER BY 1;""",
    #"k2_1": "select pealkiri from laulud l where pealkiri like '%time%' and l.koht_finaalis <= 10 order by koht_finaalis;",
    #"k2_2": "select * from voistlused v where LENGTH(v.linn) >= 7 and RIGHT(v.linn,1) != 'n';",
    #"k2_3": """select count(*) as "laulude arv" from laulud where pealkiri like '% %' and punktid_finaalis > 100;""",
    #"k2_4": """select count(*) as "riikide arv", avg(rahvaarv) as "keskmine rahvaarv" from riigid where nimi like 'L%';""",
    #"k3_1": """select lavanimi from lauljad l where l.ansambel = '0' and synniaeg is null""",
    #"k3_2": """SELECT lavanimi, extract(year from age(current_date, synniaeg)) as hetkevanus FROM Lauljad where EXTRACT(YEAR from synniaeg) between 1995 and 2000 and LENGTH(lavanimi)<5 order by hetkevanus, lavanimi;""",
    #"k3_3": """select riik_id, count(pealkiri) as arv from laulud where punktid_finaalis > 200 group by riik_id having count(pealkiri) >= 5 order by 2 desc;""",
    #"k3_4": """select synniriik_id, count(l.lavanimi) as arv from lauljad l where ansambel = '0' group by synniriik_id having count(l.lavanimi) > 12 order by 2 desc;""",
    #"k4_1": """select v.linn, extract(year from v.finaali_kuupaev) as aasta, l.pealkiri as võidulaul from laulud l join riigid r on r.id = l.riik_id join voistlused v on v.id = l.voistlus_id where l.koht_finaalis = 1 order by 2;""",
    #"k4_2": """select la.lavanimi, la.sugu, lu.pealkiri, lu.punktid_finaalis , lu.koht_finaalis from lauljad la join esitamised e on e.laulja_id = la.id join laulud lu on e.laul_id = lu.id where la.lavanimi like 'W%' and lu.koht_finaalis is not null order by lu.koht_finaalis;""",
    #"k4_3": """select r.nimi as "riik", count(l.lavanimi) as "lauljate arv" from lauljad l join riigid r on r.id = l.synniriik_id where r.pealinn like 'L%' and l.ansambel = '0' group by r.nimi order by 2 desc""",
    #"k6_1": """select lauluriik as Riik, count(*) as "laulude arv", avg(punktid_finaalis) as "keskmine punktisumma" from v_laulud where lauluriik in ('Estonia', 'Latvia', 'Lithuania', 'Finland') and finaalis = '1' group by lauluriik;""",
    #"k6_2": """select lauluriik as riik from v_laulud group by lauluriik having count(lauluriik) < 10 order by count(lauluriik), lauluriik;""",
    #"k6_3": """select le.lavanimi, l.lauluriik as sünniriik, count(le.lavanimi) as arv from v_lauluesitamine le join v_laulud l on l.laul = le.pealkiri where le.ansambel = '0' group by le.lavanimi, l.lauluriik having count(le.lavanimi) > 1 order by 3 desc, 1;""",
    #"k6_4": """select left(pealkiri, 5) as pealkirja_algus, count(left(pealkiri, 5)) as laulude_arv from laulud l where keel like '%English%' group by pealkirja_algus order by 2 desc limit 1;""",
}

